@@ -42,7 +42,7 @@ from ansible_compat.errors import (
 from ansible_compat.loaders import colpath_from_path, yaml_from_file
 from ansible_compat.prerun import get_cache_dir
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     # https://github.com/PyCQA/pylint/issues/3240
     # pylint: disable=unsubscriptable-object
     CompletedProcess = subprocess.CompletedProcess[Any]
@@ -155,6 +155,7 @@ class Runtime:
     initialized: bool = False
     plugins: Plugins
     _has_playbook_cache: dict[tuple[str, Path | None], bool] = {}
+    require_module: bool = False
 
     def __init__(
         self,
@@ -218,6 +219,7 @@ class Runtime:
             msg = f"Found incompatible version of ansible runtime {self.version}, instead of {min_required_version} or newer."
             raise RuntimeError(msg)
         if require_module:
+            self.require_module = True
             self._ensure_module_available()
 
         # pylint: disable=import-outside-toplevel
@@ -309,7 +311,7 @@ class Runtime:
                     raise TypeError(msg)
 
                 if collection in self.collections:
-                    msg = f"Multiple versions of '{collection}' were found installed, only the first one will be used, {self.collections[collection].version} ({self.collections[collection].path})."
+                    msg = f"Another version of '{collection}' {collection_info['version']} was found installed in {path}, only the first one will be used, {self.collections[collection].version} ({self.collections[collection].path})."
                     logging.warning(msg)
                 else:
                     self.collections[collection] = Collection(
@@ -339,17 +341,20 @@ class Runtime:
         # https://github.com/ansible/ansible-lint/issues/2945
         if not Runtime.initialized:
             col_path = [f"{self.cache_dir}/collections"]
+            # noinspection PyProtectedMember
+            from ansible.utils.collection_loader._collection_finder import (  # pylint: disable=import-outside-toplevel
+                _AnsibleCollectionFinder,
+            )
+
             if self.version >= Version("2.15.0.dev0"):
                 # pylint: disable=import-outside-toplevel,no-name-in-module
                 from ansible.plugins.loader import init_plugin_loader
 
+                _AnsibleCollectionFinder(  # noqa: SLF001
+                    paths=col_path,
+                )._remove()  # pylint: disable=protected-access
                 init_plugin_loader(col_path)
             else:
-                # noinspection PyProtectedMember
-                from ansible.utils.collection_loader._collection_finder import (  # pylint: disable=import-outside-toplevel
-                    _AnsibleCollectionFinder,
-                )
-
                 # noinspection PyProtectedMember
                 # pylint: disable=protected-access
                 col_path += self.config.collections_paths
@@ -395,7 +400,9 @@ class Runtime:
         env["ANSIBLE_VERBOSE_TO_STDERR"] = "True"
 
         if set_acp:
-            env["ANSIBLE_COLLECTIONS_PATH"] = ":".join(self.config.collections_paths)
+            env["ANSIBLE_COLLECTIONS_PATH"] = ":".join(
+                list(dict.fromkeys(self.config.collections_paths)),
+            )
 
         for _ in range(self.max_retries + 1 if retry else 1):
             result = run_func(
@@ -620,6 +627,9 @@ class Runtime:
                 if result.returncode != 0:
                     _logger.error(result.stderr)
                     raise AnsibleCommandError(result)
+        if self.require_module:
+            Runtime.initialized = False
+            self._ensure_module_available()
 
     # pylint: disable=too-many-locals
     def prepare_environment(  # noqa: C901
@@ -636,6 +646,7 @@ class Runtime:
         if required_collections is None:
             required_collections = {}
 
+        self._prepare_ansible_paths()
         # first one is standard for collection layout repos and the last two
         # are part of Tower specification
         # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
@@ -646,8 +657,6 @@ class Runtime:
                 file_path = self.project_dir / req_file
             self.install_requirements(file_path, retry=retry, offline=offline)
 
-        self._prepare_ansible_paths()
-
         if not install_local:
             return
 
@@ -922,7 +931,8 @@ class Runtime:
             return
         orig_value = self.environ.get(varname, default)
         if orig_value:
-            value = [*value, *orig_value.split(":")]
+            # we just want to avoid repeating the same entries, but order is important
+            value = list(dict.fromkeys([*value, *orig_value.split(":")]))
         value_str = ":".join(value)
         if value_str != self.environ.get(varname, ""):
             self.environ[varname] = value_str
